#
# spec file for package fityk
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define somajor 4
Name:           fityk
Version:        1.3.1
Release:        bp154.2.57
Summary:        Non-linear curve fitting and data analysis
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://fityk.nieto.pl/
Source:         https://github.com/wojdyr/fityk/releases/download/v%{version}/fityk-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM fityk-support-lua-5.4.patch badshah400@gmail.com -- Support lua up to version 5.4; patch taken from upstream git commit
Patch0:         fityk-support-lua-5.4.patch
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gnuplot
BuildRequires:  libtool
BuildRequires:  lua-devel >= 5.1
BuildRequires:  ncurses-devel
BuildRequires:  nlopt-devel
BuildRequires:  python3-devel
BuildRequires:  readline-devel
BuildRequires:  swig
BuildRequires:  wxWidgets-devel >= 3
BuildRequires:  xylib-devel >= 1.0
BuildRequires:  zlib-devel
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel >= 1.35
%endif

%description
Fityk is a program for nonlinear curve-fitting of analytical
functions (especially peak-shaped) to data (usually experimental
data). It can also be used for visualization of x-y data only.

%package -n     lib%{name}%{somajor}
Summary:        Library for non-linear curve fitting and data analysis
Group:          System/Libraries

%description -n lib%{name}%{somajor}
Fityk is a program for nonlinear curve-fitting of analytical
functions (especially peak-shaped) to data (usually experimental
data). It can also be used for visualization of x-y data only.

%package     -n cfityk
Summary:        Non-linear curve fitting and data analysis, command line interface
Group:          Productivity/Scientific/Math
Recommends:     gnuplot

%description -n cfityk
Fityk is a program for nonlinear curve-fitting of analytical
functions (especially peak-shaped) to data (usually experimental
data). It can also be used for visualization of x-y data only.

This package contains command line interface for Fityk.

%package        devel
Summary:        Header files, libraries and development documentation for %{name}
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{somajor} = %{version}

%description    devel
Fityk is a program for nonlinear curve-fitting of analytical
functions (especially peak-shaped) to data (usually experimental
data). It can also be used for visualization of x-y data only.

This package contains libraries and header files for developing
applications that use Fityk library.

%package     -n python3-fityk
Summary:        Python bindings to Fityk library
Group:          Development/Libraries/Python

%description -n python3-fityk
Fityk is a program for nonlinear curve-fitting of analytical
functions (especially peak-shaped) to data (usually experimental
data). It can also be used for visualization of x-y data only.

This package contains python bindings to Fityk library.

%prep
%autosetup -p1

%build
# Force c++14 to continue using dynamic exceptions removed in c+=17
# https://github.com/wojdyr/fityk/issues/37
%if 0%{?suse_version} >= 1550
export CXXFLAGS+=' -std=c++14'
%endif
export PYTHON=%{_bindir}/python3
autoreconf -fvi
%configure \
    --enable-nlopt \
    --enable-python

make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}%{python3_sitearch}
%fdupes %{buildroot}%{python3_sitelib}

%post   -n lib%{name}%{somajor} -p /sbin/ldconfig
%postun -n lib%{name}%{somajor} -p /sbin/ldconfig

%files
%license COPYING
%doc NEWS README.md TODO
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/samples
%{_bindir}/fityk
%{_datadir}/%{name}/html/
%{_datadir}/%{name}/samples/README
%{_datadir}/%{name}/samples/*.dat
%{_datadir}/%{name}/samples/*.fit
%{_datadir}/%{name}/samples/hello.lua
%{_datadir}/icons/hicolor/*/apps/fityk.*
%{_datadir}/applications/*.desktop
%{_mandir}/man1/%{name}.*
# %%{_datadir}/pixmaps/*
%{_datadir}/mime/packages/*

%files -n lib%{name}%{somajor}
%{_libdir}/lib%{name}.so.%{somajor}*

%files -n cfityk
%{_bindir}/cfityk

%files devel
%{_includedir}/*
%{_libdir}/*.so
%{_datadir}/%{name}/samples/hello.c
%{_datadir}/%{name}/samples/hello.cc
# just as curiosity samples in other languages
%{_datadir}/%{name}/samples/hello.java
%{_datadir}/%{name}/samples/hello.pl
%{_datadir}/%{name}/samples/hello.rb
# -> fityk-python
%{_datadir}/%{name}/samples/*.py*

%files -n python3-fityk
%{python3_sitearch}/*
%{python3_sitelib}/*

%changelog
* Sun Jun 13 2021 Atri Bhattacharya <badshah400@gmail.com>
- Enforce `std=c++14` when building on openSUSE >= 1550 where
  GCC 11 is the default compiler (and uses c++17 by default)
  [gh#wojdyr/fityk#37].
* Sat Feb 13 2021 Atri Bhattacharya <badshah400@gmail.com>
- Add fityk-support-lua-5.4.patch: Support lua up to version 5.4;
  patch taken from upstream git commit and rebased for current
  version. Add BuildRequires: libtool and run autoreconf before
  configure since patch modifies configure.ac.
* Sun Feb  2 2020 Atri Bhattacharya <badshah400@gmail.com>
- Don't make python3-fityk Obsolete or Provide python-fityk (the
  python2 version) so that users may continue using the installed
  python2 version should they so wish.
* Thu Jan 30 2020 Steve Kowalik <steven.kowalik@suse.com>
- Switch to building against Python 3.
  + Rename python-fityk to python3-fityk.
- Remove unknown option from configure arguments.
- Drop usage of py_sitelib deprecated variable.
- Run spec-cleaner over the spec file.
* Fri Feb  3 2017 jengelh@inai.de
- Direct-invoke ldconfig. Update RPM groups.
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Thu Jan  5 2017 dmitry_r@opensuse.org
- Update to version 1.3.1
  * Minor changes and bug fixes, see included NEWS file for detailes
* Tue May 26 2015 dmitry_r@opensuse.org
- Update to version 1.3.0
  * See included NEWS file for detailes.
  * Remove obsolete fityk-no-compilation-date.patch
* Wed Nov 12 2014 dmitry_r@opensuse.org
- Update to version 1.2.9
  * See included NEWS file for detailes.
  * Update fityk-no-compilation-date.patch
- Move CLI binary to separate package
- Build with nonlinear optimization support
- Build python bindings to libfityk
* Fri Aug 15 2014 jengelh@inai.de
- Switch from wxWidgets 2.9 to stable-3.0 for openSUSE 13.2
* Tue Dec 31 2013 dmitry_r@opensuse.org
- Initial package, version 1.2.1
- Fix rpmlint warning "file-contains-current-date"
  * fityk-no-compilation-date.patch
